"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getCanonicalToken = exports.getTokenByKey = exports.getTokensBySymbol = exports.getTokenByAddress = exports.getNative = exports.filters = exports.isEqualCaseInsensitive = exports.getTokenMap = void 0;
//import { mainnetTokenDetails } from './mainnetTokenDetails.js';
//import { testnetTokenDetails } from './testnetTokenDetails.js';
const mainnet_js_1 = require("./mainnet.js");
const testnet_js_1 = require("./testnet.js");
function getTokenMap(network, chain) {
    if (network === "Devnet")
        return;
    if (network === "Mainnet") {
        if (!mainnet_js_1.mainnetChainTokens.has(chain))
            return;
        const chainTokens = mainnet_js_1.mainnetChainTokens.get(chain);
        return Object.fromEntries(chainTokens.map(([key, token]) => [key, { ...token, chain, key }]));
    }
    if (network === "Testnet") {
        if (!testnet_js_1.testnetChainTokens.has(chain))
            return;
        const chainTokens = testnet_js_1.testnetChainTokens.get(chain);
        return Object.fromEntries(chainTokens.map(([key, token]) => [key, { ...token, chain, key }]));
    }
    throw "Unsupported network: " + network;
}
exports.getTokenMap = getTokenMap;
const isEqualCaseInsensitive = (a, b) => {
    return a.toLowerCase() === b.toLowerCase();
};
exports.isEqualCaseInsensitive = isEqualCaseInsensitive;
exports.filters = {
    byAddress: (tokenMap, address) => {
        return Object.values(tokenMap).find((token) => (0, exports.isEqualCaseInsensitive)(token.address, address));
    },
    native: (tokenMap) => {
        return exports.filters.byAddress(tokenMap, "native");
    },
    bySymbol: (tokenMap, symbol) => {
        const foundTokens = Object.values(tokenMap).filter((token) => token.symbol === symbol);
        return foundTokens && foundTokens.length > 0 ? foundTokens : undefined;
    },
    byKey: (tokenMap, key) => {
        const foundToken = Object.entries(tokenMap).find(([_key]) => key === _key);
        return foundToken ? foundToken[1] : undefined;
    },
};
// The token that represents the native gas token on a given chain
// also represented as the string 'native' where applicable
function getNative(network, chain) {
    const tokenMap = getTokenMap(network, chain);
    return tokenMap ? exports.filters.native(tokenMap) : undefined;
}
exports.getNative = getNative;
// Finds the (first) unique token key for a given chain and address
function getTokenByAddress(network, chain, address) {
    const tokenMap = getTokenMap(network, chain);
    return tokenMap ? exports.filters.byAddress(tokenMap, address) : undefined;
}
exports.getTokenByAddress = getTokenByAddress;
function getTokensBySymbol(network, chain, symbol) {
    const tokenMap = getTokenMap(network, chain);
    return tokenMap ? exports.filters.bySymbol(tokenMap, symbol) : undefined;
}
exports.getTokensBySymbol = getTokensBySymbol;
// Finds the (first) unique token key for a given chain and symbol
function getTokenByKey(network, chain, key) {
    const tokenMap = getTokenMap(network, chain);
    return tokenMap ? exports.filters.byKey(tokenMap, key) : undefined;
}
exports.getTokenByKey = getTokenByKey;
// The Canonical token is the token that the input key resolves to
// from its original chain. For example, if the input key is
// USDCeth, the canonical token is USDC on ETH
function getCanonicalToken(network, chain, key) {
    const token = getTokenByKey(network, chain, key);
    if (!token)
        return;
    if (!token.original)
        return token;
    const original = getTokensBySymbol(network, token.original, token.symbol);
    if (!original)
        return;
    // return the the token with this symbol where no `original` field exists
    return original.find((t) => !t.original);
}
exports.getCanonicalToken = getCanonicalToken;
//# sourceMappingURL=index.js.map